<TeXmacs|1.0.7.3>

<style|<tuple|article|maxima>>

<\body>
  <section|Constant density>

  We consider the vertical cross-section in a wind-driven lake of constant
  depth <math|H> and horizontal extent <math|L>. The kinematic viscosity
  <math|\<nu\>> is constant. A no-slip condition is applied on the bottom
  boundary (<math|u=w=0>). The top boundary is a ``rigid lid'' and the effect
  of the wind is modelled as an imposed velocity gradient i.e. <math|w=0> and
  <math|\<partial\><rsub|z>u=\<tau\>>. The left and right wall use ``slip
  conditions'' i.e. (<math|u=0>, <math|\<partial\><rsub|x>w=0>). The
  assumption of a rigid lid rather than a free surface is justified when the
  speed of the gravity waves <math|<sqrt|g*H>> is large compared to the
  physical velocities (i.e. the Froude number is small) or equivalently, when
  the slope of the free surface is small. Using dimensional arguments, this
  slope can be estimated as

  <\equation*>
    <frac|\<nu\>*\<tau\>|g*H>
  </equation*>

  The independent dimensionless numbers controlling the problem then are:

  <\itemize-dot>
    <item>the aspect ratio <math|a=L/H>,

    <item>a Reynolds number <math|Re=H*<rsup|2>\<tau\>/\<nu\>>,

    <item>the free-surface slope <math|\<alpha\>=\<nu\>*\<tau\>/g*H>.
  </itemize-dot>

  In the following, we consider only dimensionless quantities where <math|H>
  has been taken as length scale and <math|1/\<tau\>> as time scale.
  <with|color|blue|Note that the rigid-lid approximation is only valid in the
  limit of vanishing <math|\<alpha\>>.>

  An analytical solution for this problem can be obtained in the limit of
  large <math|a> and assuming a parallel flow. A parabolic velocity profile
  of the form

  <\equation*>
    u(z)=A*z<rsup|2>+B*z+C
  </equation*>

  is sought. An additional constraint must thus be added to the two boundary
  conditions above in order to close the system. This is provided by
  observing that volume conservation requires that the depth-averaged
  velocity be zero. One then easily gets

  <\equation*>
    u(z)=<frac|z|4>*<left|(>3*z<rsup|>-2<right|)>.
  </equation*>

  This can also be used to refine the free-surface slope estimate using the
  equilibrium relationship

  <\equation*>
    \<partial\><rsup|2><rsub|z<rsup|2>>u=<frac|\<alpha\><rprime|'>*|\<alpha\>>,
  </equation*>

  where we assume hydrostatic balance. For the parabolic velocity profile,
  this gives

  <\equation>
    \<alpha\><rprime|'>=<frac|3|2>*\<alpha\><label|slope>
  </equation>

  In the case of a finite aspect ratio <math|a>, we expect this solution to
  be valid only in the center of the lake, where the hypothesis of parallel
  flow should be verified. The ``upwelling'' and ``downwelling'' zones close
  to the side walls will of course not be described by this solution.

  To verify this hypothesis, we used Gerris to solve the incompressible
  Navier-Stokes equations in a rectangular domain with the boundary
  conditions given above. For low Reynolds numbers, a stationary solution to
  this variant of the ``lid-driven cavity'' problem can be readily obtained.
  Figure <reference|vectors> illustrates the stationary solution obtained
  numerically for <math|a=4>, <math|Re=1>, <with|color|blue|discretised with
  32 points vertically and 256 points horizontally (only one in 8 vectors is
  plotted horizontally).>

  <big-figure|<postscript|stretch/vectors.eps|0.8par|||||>|Velocity field for
  the wind-driven lake. <math|a=4>, <math|Re=1>.<label|vectors>>

  Figure <reference|profile> illlustrates the velocity profile obtained
  numerically in the center of the lake together with the analytical
  solution.

  <big-figure|<postscript|stretch/finer/profile.eps|0.7par|||||>|Velocity
  profile in the center of the lake. <math|a=4>, <math|Re=1>.<label|profile>>

  It is clear that the analytical solution is a good approximation even for
  this low aspect ratio. An indication of the lower limit of validity of the
  solution is given by Figure <reference|convergence> and
  <reference|pressure-convergence> where the aspect ratio has been varied
  from 1 to 8 while keeping all the other parameters constant.\ 

  <big-figure|<postscript|stretch/finer/convergence.eps|0.7par|||||>|Convergence
  of the velocity profiles in the center of the lake as a function of the
  aspect ratio. <math|Re=1>.<label|convergence>>

  <big-figure|<postscript|stretch/finer/convergence-pressure-1.eps|0.7par|||||>|Values
  of pressure at the bottom together with the analytical solution (equation
  (<reference|slope>)). <math|a=4>, <math|Re=1>.<label|pressure-convergence>>

  What is the effect of the Reynolds number? Figure <reference|Re400>
  illustrates the stationary velocity field obtained for <math|a=4> and
  <math|Re=400>. There is a clear lateral asymmetry with a strong localised
  downwelling and a broad and weak upwelling compared to Figure
  <reference|vectors>. Note that this is similar to what is classically
  observed for the lid-driven cavity problem at comparable Reynolds numbers
  (with aspect ratios close to unity).

  <\big-figure>
    <postscript|stretch/vectors-400.eps|0.8par|||||>
  </big-figure|Velocity field for the wind-driven lake. <math|a=4>,
  <math|Re=400>.<label|Re400>>

  This asymmetry also affects the assumption of parallel flow in the center
  of the lake and the analytical solution is only recovered for significantly
  larger aspect ratios (Figure <reference|convergence-40>). The same holds
  for the pressure profiles (Figure <reference|convergence-pressure-400>).

  <big-figure|<postscript|stretch/finer/convergence-400.eps|0.7par|||||>|Convergence
  of the velocity profiles in the center of the lake as a function of the
  aspect ratio. <math|Re=400>.<label|convergence-40>>

  <big-figure|<postscript|stretch/finer/convergence-pressure-400.eps|0.7par|||||>|Convergence
  of the bottom pressure profiles as a function of the aspect ratio.
  <math|Re=400>.<label|convergence-pressure-400>>

  The lateral upwelling and downwelling are important features of the
  wind-driven circulation and it is useful to caracterise their lateral
  extent. This can be done using several methods. Given the good predictions
  in the center of the lake obtained with the simple parallel flow analytical
  model, one way to caracterise the lateral currents is to measure the
  departure from the parallel flow analytical solution. We define the
  depth-averaged <with|color|blue|relative> root-mean-square (RMS) error norm
  as

  <\equation*>
    e<rsub|RMS>(x)=<sqrt|<big|int>(u(x,z)-u<rsub|analytical>(z))<rsup|2>*d
    z>/<sqrt|<big|int>u<rsup|2><rsub|analytical>(z)*d z>,
  </equation*>

  <with|color|blue|where<with|mode|math|<sqrt|<big|int>u<rsup|2><rsub|analytical>(z)*d
  z>\<simeq\>0.091>.>

  Figure <reference|xprofile> illustrate this error distribution for
  <math|Re=1> and <math|Re=400> for different aspect ratios. Consistently
  with Figures <reference|convergence> and <reference|convergence-400>, the
  error in Figure <reference|xprofile>.a is negligible in the center of the
  lake for aspect ratios larger than 4, while the error in Figure
  <reference|xprofile>.b is still significant for <math|a=16>. The asymmetry
  of the flow for <math|Re=400> is also evident.

  <big-figure|<tabular*|<tformat|<table|<row|<cell|<postscript|stretch/finer/xprofile.eps|0.45par|||||>>|<cell|<postscript|stretch/finer/xprofile-400.eps|0.45par|||||>>>|<row|<cell|(a)>|<cell|(b)>>>>>|Error
  distribution <math|e<rsub|RMS>(x)> for (a) <math|Re=1> (b)
  <math|Re=400>.<label|xprofile>>

  It is clear that as the central part of the lake converges toward the
  parallel flow solution (with increasing aspect ratio), the solutions for
  the lateral upwelling and downwelling should become independent from each
  other and thus from the aspect ratio. This can be verified by changing the
  reference of the horizontal axis of Figure <reference|xprofile> to make it
  coincide with the lateral boundaries. This is what is done in Figure
  <reference|xprofile-lateral>.

  <big-figure|<tabular*|<tformat|<table|<row|<cell|<postscript|stretch/finer/xprofile-lateral.eps|0.45par|||||>>|<cell|<postscript|stretch/finer/xprofile-lateral-400.eps|0.45par|||||>>>|<row|<cell|(a)>|<cell|(b)>>>>>|Error
  distribution <math|e<rsub|RMS>(x)> for (a) <math|Re=1> (b)
  <math|Re=400>.<label|xprofile-lateral>>

  An alternative description of the lateral upwelling and downwelling is
  given by looking at the depth-averaged vertical velocity profile (Figures
  <reference|wprofile> and <reference|wprofile-lateral>).

  <big-figure|<tabular*|<tformat|<table|<row|<cell|<postscript|stretch/finer/wprofile.eps|0.45par|||||>>|<cell|<postscript|stretch/finer/wprofile-400.eps|0.45par|||||>>>|<row|<cell|(a)>|<cell|(b)>>>>>|Depth-averaged
  vertical velocity <math|<wide|w|\<bar\>>(x)> for (a) <math|Re=1> (b)
  <math|Re=400>.<label|wprofile>>

  <big-figure|<tabular*|<tformat|<table|<row|<cell|<postscript|stretch/finer/wprofile-lateral.eps|0.45par|||||>>|<cell|<postscript|stretch/finer/wprofile-lateral-400.eps|0.45par|||||>>>|<row|<cell|(a)>|<cell|(b)>>>>>|Depth-averaged
  vertical velocity <math|<wide|w|\<bar\>>(x)> for (a) <math|Re=1> (b)
  <math|Re=400>.<label|wprofile-lateral>>

  The lateral extent of the downwelling region can be quantified for instance
  by the width <math|(a/2-x<rsub|0>)> where <math|x<rsub|0>> is the location
  where

  <\equation*>
    <wide|w|\<bar\>>(x<rsub|0>)/min(<wide|w|\<bar\>>(x))<rsub|x>\<gtr\>0.1
  </equation*>

  Figure <reference|reynolds> shows the dependency of the downwelling extent
  on the Reynolds number. The downwelling width seems to reach an asymptote
  for large Reynolds numbers. To check that this result is not affected by
  numerical viscosity two resolutions are shown in Figure
  <reference|reynolds>.

  <big-figure|<postscript|stretch/finer/re.eps|0.7par|||||>|Width of the
  downwelling zone as a function of the Reynolds number for <math|a=4>. Two
  spatial resolutions are shown to check for convergence.<label|reynolds>>

  <big-figure|<tabular*|<tformat|<table|<row|<cell|<postscript|stretch/finer/uminmax-1.eps|0.7par|||||>>>|<row|<cell|<postscript|stretch/finer/uminmax-400.eps|0.7par|||||>>>>>>|<math|max(u(x,z))>
  and <math|min(u(x,z))> as functions of <math|x> for <math|Re=1> (top) and
  <math|Re=400> (bottom).>

  <big-figure|<tabular*|<tformat|<table|<row|<cell|<postscript|stretch/finer/znull-1.eps|0.7par|||||>>>|<row|<cell|<postscript|stretch/finer/znull-400.eps|0.7par|||||>>>>>>|Position
  <math|z<rsub|null>(x)> where <math|u(x,z<rsub|null>)=0> as a function of
  <math|x> for <math|Re=1> (top) and <math|Re=400> (bottom).>

  <subsection|Parabolic bathymetry>

  We now consider a lake with variable depth

  <\equation*>
    H(x)=(1-h<rsub|min>)*<left|(>1-4*<frac|x<rsup|2>|a<rsup|2>><right|)>+h<rsub|min>
  </equation*>

  with <math|h<rsub|min>=0.1>

  <big-figure|<postscript|stretch/parabolic/hmin/vectors.eps|0.8par|||||>|Velocity
  field for the wind-driven lake. <math|a=4>,
  <math|Re=1>.<label|vectors-para>>

  <big-figure|<postscript|stretch/parabolic/hmin/convergence.eps|0.7par|||||>|Convergence
  of the velocity profiles in the center of the lake as a function of the
  aspect ratio. <math|Re=1>.<label|convergence-para>>

  <\big-figure>
    <postscript|stretch/parabolic/hmin/vectors-400.eps|0.8par|||||>
  </big-figure|Velocity field for the wind-driven lake. <math|a=4>,
  <math|Re=400>.<label|Re400-para>>

  <big-figure|<postscript|stretch/parabolic/hmin/convergence-400.eps|0.7par|||||>|Convergence
  of the velocity profiles in the center of the lake as a function of the
  aspect ratio. <math|Re=400>.<label|convergence-400-para>>

  In contrast to the constant-depth case, we expect the boundary currents to
  scale like the bathymetry so that the relevant variable now is <math|x/a>.
  This scaling is confirmed by the convergence observed for large aspect
  ratios in Figure <reference|wprofile-lateral-para>. The magnitude of the
  vertical velocity is expected to scale like <math|1/a> (Figure
  <reference|wprofile-lateral-para>).

  <\big-figure|<tabular*|<tformat|<table|<row|<cell|<postscript|stretch/parabolic/hmin/wprofile-lateral.eps|0.45par|||||>>|<cell|<postscript|stretch/parabolic/hmin/wprofile-lateral-400.eps|0.45par|||||>>>|<row|<cell|(a)>|<cell|(b)>>>>>>
    Normalised depth-averaged vertical velocity <math|a*<wide|w|\<bar\>>(x)>
    as a function of normalised abscissa <math|x/a> for (a) <math|Re=1> (b)
    <math|Re=400>.<label|wprofile-lateral-para>
  </big-figure>

  <big-figure|<tabular*|<tformat|<table|<row|<cell|<postscript|stretch/parabolic/hmin/uminmax-1.eps|0.7par|||||>>>|<row|<cell|<postscript|stretch/parabolic/hmin/uminmax-400.eps|0.7par|||||>>>>>>|<math|max(u(x,z))>
  and <math|min(u(x,z))> as functions of <math|x> for <math|Re=1> (top) and
  <math|Re=400> (bottom).>

  <big-figure|<tabular*|<tformat|<table|<row|<cell|<postscript|stretch/parabolic/hmin/znull-1.eps|0.7par|||||>>>|<row|<cell|<postscript|stretch/parabolic/hmin/znull-400.eps|0.7par|||||>>>>>>|Position
  <math|z<rsub|null>(x)> where <math|u(x,z<rsub|null>)=0> as a function of
  <math|x> for <math|Re=1> (top) and <math|Re=400> (bottom).>

  <big-figure|<tabular*|<tformat|<table|<row|<cell|<postscript|stretch/parabolic/hmin/convergence-pressure-1.eps|0.7par|||||>>>|<row|<cell|<postscript|stretch/parabolic/hmin/convergence-pressure-400.eps|0.7par|||||>>>>>>|Pressure
  at the bottom for <math|Re=1> (top) and <math|Re=400> (bottom).>

  <subsubsection|Three-dimensional paraboloidal bathymetry>

  The depth is described by

  <\equation*>
    H(x,y)=(1-h<rsub|min>)*<left|(>1-4*<frac|x*<rsup|2>+y<rsup|2>|a<rsup|2>><right|)>+h<rsub|min>
  </equation*>

  with <math|h<rsub|min>=0.1>

  Each dimension is discretised with 32 grid points. The overall stationary
  circulation is depicted in Figure <reference|3D>. The vertical profile of
  horizontal velocity at the center of the lake is given in Figure
  <reference|3Dprofile> together with the analytical model. While the 3D
  solution does verify the top and bottom boundary conditions, it does not
  verify the additional constraint of volume conservation in a vertical slice
  (i.e. nullity of the depth-averaged horizontal velocity). This is not
  surprising since the flow structure is clearly three-dimensional and
  horizontal divergence also needs to be taken into account when looking at
  volume conservation.

  <big-figure|<tabular*|<tformat|<table|<row|<cell|<postscript|stretch/parabolic/3D/hmin/vectors-front.eps|0.8par|||||>>>|<row|<cell|(a)>>|<row|<cell|<postscript|stretch/parabolic/3D/hmin/vectors-top.eps|0.8par|||||>>>|<row|<cell|(b)>>>>>|Velocity
  field for the three-dimensional wind-driven lake. <math|a=8>,
  <math|Re=400>. (a) cross-section at <math|y=0>. (b) cross-section at
  <math|z=0>. <with|color|blue|The velocity field is indeed two-dimensional
  rather than the ``one-dimensional'' field of the hydrostatic version. I
  don't really have an explanation for the difference: one guess is that the
  missing terms in the hydrostatic approximation (either the missing
  horizontal diffusion of the vertical velocity or the non-hydrostatic
  pressure terms) cause the field to be 1D rather than 2D.><label|3D>>

  <big-figure|<postscript|stretch/parabolic/3D/hmin/lake-8-400..eps|0.7par|||||>|Vertical
  profile in the center of the lake. <math|a=8>,
  <math|Re=400>.<label|3Dprofile>>

  <big-figure|<postscript|stretch/parabolic/3D/hmin/vectors-average-top.eps|0.7par|||||>|Depth-averaged
  horizontal velocity field. <math|a=8>, <math|Re=400>.>

  <big-figure|<postscript|stretch/parabolic/3D/hmin/v-average-top.eps|0.7par|||||>|Depth-averaged
  vertical velocity field. <math|a=8>, <math|Re=400>.>

  <big-figure|<postscript|stretch/parabolic/3D/hmin/p-average-top.eps|0.7par|||||>|Depth-averaged
  pressure field. <math|a=8>, <math|Re=400>.>

  <section|Stratified lake>

  <with|color|blue|I have kept this section for now. I could easily do a
  smooth, diffusive stratification, however there are two problems I can see
  when doing this: 1) are there stationary solutions? 2) are there analytical
  solutions for the stationary solutions? If it is unstationary, it is more
  complicated. May be we could forget about stratification to start with?>

  We now consider the case of a stratified lake. To model the stable thermal
  stratification often observed in lakes, we assume a vertical density
  profile of the form

  <\equation*>
    \<rho\>(z)=\<rho\><rsub|0>-H<rsub|eaviside>(z-H+H<rsub|thermocline>)*\<Delta\>\<rho\>.
  </equation*>

  If <math|\<Delta\>\<rho\>/\<rho\><rsub|0>> is small compared to one, we can
  use a Boussinesq approximation and this results in an additional source
  term <math|-g<rprime|'>*H<rsub|eaviside>(z-H+H<rsub|thermocline>)> for the
  vertical co<math|>mponent of velocity, with <math|g<rprime|'>> the reduced
  gravity

  <\equation*>
    g<rprime|'>=<frac|\<Delta\>\<rho\>|\<rho\><rsub|0>>*g.
  </equation*>

  Through dimensional arguments one can find that the equilibrium slope
  <math|\<alpha\><rsub|t>> of the thermocline should verify the relation

  <\equation*>
    g<rprime|'>*\<alpha\><rsub|t>* \ \ \ \ \ \<propto\>
    \ \ \ \ \ \ \ \<nu\>*\<tau\>,
  </equation*>

  for vanishing <math|\<alpha\><rsub|t>>.

  We then need to consider two additional independent dimensionless
  parameters

  <\itemize-dot>
    <item><math|b=1-H<rsub|thermocline>/H>, set to <math|3/4> in what
    follows,

    <item>and the thermocline slope

    <\equation*>
      \<alpha\><rsub|t>=<frac|\<nu\>*\<tau\>|g<rprime|'>*H>
    </equation*>
  </itemize-dot>

  If we again assume parallel flow, an analytical solution can be sought for
  the horizontal velocity profile in a vertical cross-section, of the form

  <\eqnarray*>
    <tformat|<table|<row|<cell|u(z)=A<rsub|1>*z<rsup|2>+B<rsub|1>*z+C<rsub|1>>|<cell|>|<cell|for
    z \<gtr\>b,>>|<row|<cell|u(z)=A<rsub|2>*z<rsup|2>+B<rsub|2>*z+C<rsub|2>>|<cell|>|<cell|for
    z \<leqslant\> b,>>>>
  </eqnarray*>

  with the boundary conditions

  <\eqnarray*>
    <tformat|<table|<row|<cell|\<partial\><rsub|z>u=1>|<cell|>|<cell|at
    z=1,>>|<row|<cell|u=0>|<cell|>|<cell|at z
    =0,>>|<row|<cell|u\|<rsub|z\<gtr\>b>=u\|<rsub|z\<less\>b>>|<cell|>|<cell|at
    z=b,>>|<row|<cell|\<partial\><rsub|z>u\|<rsub|z\<gtr\>b>=\<partial\><rsub|z>u\|<rsub|z\<less\>b>>|<cell|>|<cell|at
    z=b,>>>>
  </eqnarray*>

  and the volume conservation conditions

  <\eqnarray*>
    <tformat|<table|<row|<cell|<big|int><rsup|1><rsub|b>>|<cell|A<rsub|1>*z<rsup|2>+B<rsub|1>*z+C<rsub|1>*d
    z>|<cell|= 0,>>|<row|<cell|<big|int><rsup|b><rsub|0>>|<cell|A<rsub|2>*z<rsup|2>+B<rsub|2>*z+C<rsub|2>*d
    z>|<cell|= 0.>>>>
  </eqnarray*>

  Developing gives

  <\eqnarray*>
    <tformat|<table|<row|<cell|2*A<rsub|1>+B<rsub|1>>|<cell|=>|<cell|1>>|<row|<cell|A<rsub|1>*b<rsup|2>+B<rsub|1>*b+C<rsub|1>>|<cell|=>|<cell|A<rsub|2>*b<rsup|2>+B<rsub|2>*b>>|<row|<cell|2*A<rsub|1>*b+B<rsub|1>>|<cell|=>|<cell|2*A<rsub|2>*b+B<rsub|2>>>|<row|<cell|A<rsub|1>*(1-b<rsup|3>)/3+B<rsub|1>*(1-b<rsup|2>)/2+C<rsub|1>*(1-b)>|<cell|=>|<cell|0>>|<row|<cell|A<rsub|2>*b<rsup|3>/3+B<rsub|2>*b<rsup|2>/2>|<cell|=>|<cell|0>>>>
  </eqnarray*>

  For <math|b=3/4>, this readily gives

  <\eqnarray*>
    <tformat|<table|<row|<cell|u(z)=<frac|30*z<rsup|2>-47*z+18|13>>|<cell|>|<cell|for
    z \<gtr\>3/4,>>|<row|<cell|u(z)=<frac|-2*z<rsup|2>+z|13>>|<cell|>|<cell|for
    z \<leqslant\> 3/4.>>>>
  </eqnarray*>

  This can be used to refine the estimates of the thermocline and surface
  slopes. Assuming hydrostatic balance, the horizontal pressure gradient is
  given by

  <\eqnarray*>
    <tformat|<table|<row|<cell|\<partial\><rsub|x>p=g*\<alpha\><rprime|'>>|<cell|>|<cell|for
    z \<gtr\>3/4*+\<alpha\><rsub|t><rprime|'>*x,>>|<row|<cell|\<partial\><rsub|x>p=g*\<alpha\><rprime|'>*+g<rprime|'>*\<alpha\><rsub|t><rprime|'>*>|<cell|>|<cell|for
    z \<leqslant\>3/4*+\<alpha\><rsub|t><rprime|'>*x.>>>>
  </eqnarray*>

  Balancing the horizontal pressure gradients and viscous stress then gives

  <\eqnarray*>
    <tformat|<table|<row|<cell|\<alpha\><rprime|'>>|<cell|=>|<cell|<frac|60|13>*\<alpha\><eq-number><label|alpha-strat>>>|<row|<cell|\<alpha\><rsub|t><rprime|'>>|<cell|=>|<cell|-<frac|64|13>*\<alpha\><rsub|t><eq-number><label|alphat-strat>>>>>
  </eqnarray*>

  The interface between the two layers is tracked numerically using a
  Volume-Of-Fluid (VOF) scheme which is non-diffusive. Figure
  <reference|vectors-strat> illustrates the stationary velocity field as well
  as the interface between the two layers.

  <big-figure|<postscript|stretch/stratified/vectors-400.eps|0.8par|||||>|Velocity
  field for the wind-driven lake. <math|a=4>, <math|Re=400>,
  <math|\<alpha\><rsub|t>=1/400>.<label|vectors-strat>>

  Figure <reference|convergence-strat> illlustrates the convergence of the
  velocity profile obtained numerically in the center of the lake toward the
  analytical solution.

  <big-figure|<postscript|stretch/stratified/convergence-400.eps|0.7par|||||>|Convergence
  of the velocity profiles in the center of the lake as a function of the
  aspect ratio. <math|Re=400>, <math|\<alpha\><rsub|t>=1/400>.<label|convergence-strat>>

  <big-figure|<postscript|stretch/stratified/convergence-pressure-400.eps|0.7par|||||>|Convergence
  of the surface pressure profiles as a function of the aspect ratio.
  <math|Re=400>, <math|\<alpha\><rsub|t>=1/400>. The analytical solution is
  given by (<reference|alpha-strat>).<label|convergence-strat>>

  <\big-figure|<postscript|stretch/stratified/convergence-thermocline-400.eps|0.7par|||||>>
    Convergence of the thermocline profiles as a function of the aspect
    ratio. <math|Re=400>, <math|\<alpha\><rsub|t>=1/400>. The analytical
    solution is given by (<reference|alphat-strat>).<label|convergence-thermocline>
  </big-figure>

  <\big-figure>
    <postscript|stretch/stratified/xprofile-400.eps|0.7par|||||>
  </big-figure|Error distribution <math|e<rsub|RMS>(x)> for <math|Re=400>,
  <math|\<alpha\><rsub|t>=1/400>.<label|xprofile-strat>>

  <\big-figure>
    <postscript|stretch/stratified/xprofile-lateral-400.eps|0.7par|||||>
  </big-figure|Error distribution <math|e<rsub|RMS>(x)> for <math|Re=400>,
  <math|\<alpha\><rsub|t>=1/400>.<label|xprofile-lateral-strat>>
</body>

<\references>
  <\collection>
    <associate|3D|<tuple|23|10>>
    <associate|3Dprofile|<tuple|24|10>>
    <associate|Re100|<tuple|4|?>>
    <associate|Re400|<tuple|5|4>>
    <associate|Re400-para|<tuple|17|8>>
    <associate|alpha-strat|<tuple|2|12>>
    <associate|alphat-strat|<tuple|3|12>>
    <associate|auto-1|<tuple|1|1>>
    <associate|auto-10|<tuple|9|6>>
    <associate|auto-11|<tuple|10|6>>
    <associate|auto-12|<tuple|11|6>>
    <associate|auto-13|<tuple|12|7>>
    <associate|auto-14|<tuple|13|7>>
    <associate|auto-15|<tuple|14|7>>
    <associate|auto-16|<tuple|1.1|7>>
    <associate|auto-17|<tuple|15|8>>
    <associate|auto-18|<tuple|16|8>>
    <associate|auto-19|<tuple|17|8>>
    <associate|auto-2|<tuple|1|2>>
    <associate|auto-20|<tuple|18|9>>
    <associate|auto-21|<tuple|19|9>>
    <associate|auto-22|<tuple|20|9>>
    <associate|auto-23|<tuple|21|9>>
    <associate|auto-24|<tuple|22|10>>
    <associate|auto-25|<tuple|1.1.1|10>>
    <associate|auto-26|<tuple|23|11>>
    <associate|auto-27|<tuple|24|12>>
    <associate|auto-28|<tuple|25|12>>
    <associate|auto-29|<tuple|26|13>>
    <associate|auto-3|<tuple|2|2>>
    <associate|auto-30|<tuple|27|13>>
    <associate|auto-31|<tuple|2|14>>
    <associate|auto-32|<tuple|28|14>>
    <associate|auto-33|<tuple|29|?>>
    <associate|auto-34|<tuple|30|?>>
    <associate|auto-35|<tuple|31|?>>
    <associate|auto-36|<tuple|32|?>>
    <associate|auto-37|<tuple|33|?>>
    <associate|auto-4|<tuple|3|3>>
    <associate|auto-5|<tuple|4|3>>
    <associate|auto-6|<tuple|5|4>>
    <associate|auto-7|<tuple|6|4>>
    <associate|auto-8|<tuple|7|5>>
    <associate|auto-9|<tuple|8|5>>
    <associate|convergence|<tuple|3|3>>
    <associate|convergence-40|<tuple|6|4>>
    <associate|convergence-400|<tuple|6|4>>
    <associate|convergence-400-para|<tuple|18|8>>
    <associate|convergence-para|<tuple|16|7>>
    <associate|convergence-pressure-400|<tuple|7|5>>
    <associate|convergence-slope|<tuple|26|?>>
    <associate|convergence-strat|<tuple|30|13>>
    <associate|convergence-thermocline|<tuple|31|13>>
    <associate|pressure-convergence|<tuple|4|?>>
    <associate|pressure-profile|<tuple|4|3>>
    <associate|profile|<tuple|2|2>>
    <associate|profile-para|<tuple|16|7>>
    <associate|profile-strat|<tuple|24|?>>
    <associate|re100|<tuple|4|?>>
    <associate|reynolds|<tuple|12|?>>
    <associate|slope|<tuple|1|2>>
    <associate|vectors|<tuple|1|2>>
    <associate|vectors-para|<tuple|15|7>>
    <associate|vectors-strat|<tuple|28|12>>
    <associate|wprofile|<tuple|10|6>>
    <associate|wprofile-lateral|<tuple|11|6>>
    <associate|wprofile-lateral-para|<tuple|19|9>>
    <associate|wprofile-para|<tuple|19|9>>
    <associate|xprofile|<tuple|8|5>>
    <associate|xprofile-lateral|<tuple|9|6>>
    <associate|xprofile-lateral-para|<tuple|19|9>>
    <associate|xprofile-lateral-strat|<tuple|33|14>>
    <associate|xprofile-para|<tuple|19|8>>
    <associate|xprofile-strat|<tuple|32|14>>
  </collection>
</references>

<\auxiliary>
  <\collection>
    <\associate|figure>
      <tuple|normal|Velocity field for the wind-driven lake.
      <with|mode|<quote|math>|a=4>, <with|mode|<quote|math>|Re=1>.<label|vectors>|<pageref|auto-2>>

      <tuple|normal|Velocity profile in the center of the lake.
      <with|mode|<quote|math>|a=4>, <with|mode|<quote|math>|Re=1>.<label|profile>|<pageref|auto-3>>

      <tuple|normal|Convergence of the velocity profiles in the center of the
      lake as a function of the aspect ratio.
      <with|mode|<quote|math>|Re=1>.<label|convergence>|<pageref|auto-4>>

      <tuple|normal|Values of pressure at the bottom together with the
      analytical solution (equation (<reference|slope>)).
      <with|mode|<quote|math>|a=4>, <with|mode|<quote|math>|Re=1>.<label|pressure-convergence>|<pageref|auto-5>>

      <tuple|normal|Velocity field for the wind-driven lake.
      <with|mode|<quote|math>|a=4>, <with|mode|<quote|math>|Re=400>.<label|Re400>|<pageref|auto-6>>

      <tuple|normal|Convergence of the velocity profiles in the center of the
      lake as a function of the aspect ratio.
      <with|mode|<quote|math>|Re=400>.<label|convergence-40>|<pageref|auto-7>>

      <tuple|normal|Convergence of the bottom pressure profiles as a function
      of the aspect ratio. <with|mode|<quote|math>|Re=400>.<label|convergence-pressure-400>|<pageref|auto-8>>

      <tuple|normal|Error distribution <with|mode|<quote|math>|e<rsub|RMS>(x)>
      for (a) <with|mode|<quote|math>|Re=1> (b)
      <with|mode|<quote|math>|Re=400>.<label|xprofile>|<pageref|auto-9>>

      <tuple|normal|Error distribution <with|mode|<quote|math>|e<rsub|RMS>(x)>
      for (a) <with|mode|<quote|math>|Re=1> (b)
      <with|mode|<quote|math>|Re=400>.<label|xprofile-lateral>|<pageref|auto-10>>

      <tuple|normal|Depth-averaged vertical velocity
      <with|mode|<quote|math>|<wide|w|\<bar\>>(x)> for (a)
      <with|mode|<quote|math>|Re=1> (b) <with|mode|<quote|math>|Re=400>.<label|wprofile>|<pageref|auto-11>>

      <tuple|normal|Depth-averaged vertical velocity
      <with|mode|<quote|math>|<wide|w|\<bar\>>(x)> for (a)
      <with|mode|<quote|math>|Re=1> (b) <with|mode|<quote|math>|Re=400>.<label|wprofile-lateral>|<pageref|auto-12>>

      <tuple|normal|Width of the downwelling zone as a function of the
      Reynolds number for <with|mode|<quote|math>|a=4>. Two spatial
      resolutions are shown to check for convergence.<label|reynolds>|<pageref|auto-13>>

      <tuple|normal|<with|mode|<quote|math>|max(u(x,z))> and
      <with|mode|<quote|math>|min(u(x,z))> as functions of
      <with|mode|<quote|math>|x> for <with|mode|<quote|math>|Re=1> (top) and
      <with|mode|<quote|math>|Re=400> (bottom).|<pageref|auto-14>>

      <tuple|normal|Position <with|mode|<quote|math>|z<rsub|null>(x)> where
      <with|mode|<quote|math>|u(x,z<rsub|null>)=0> as a function of
      <with|mode|<quote|math>|x> for <with|mode|<quote|math>|Re=1> (top) and
      <with|mode|<quote|math>|Re=400> (bottom).|<pageref|auto-15>>

      <tuple|normal|Velocity field for the wind-driven lake.
      <with|mode|<quote|math>|a=4>, <with|mode|<quote|math>|Re=1>.<label|vectors-para>|<pageref|auto-17>>

      <tuple|normal|Convergence of the velocity profiles in the center of the
      lake as a function of the aspect ratio.
      <with|mode|<quote|math>|Re=1>.<label|convergence-para>|<pageref|auto-18>>

      <tuple|normal|Velocity field for the wind-driven lake.
      <with|mode|<quote|math>|a=4>, <with|mode|<quote|math>|Re=400>.<label|Re400-para>|<pageref|auto-19>>

      <tuple|normal|Convergence of the velocity profiles in the center of the
      lake as a function of the aspect ratio.
      <with|mode|<quote|math>|Re=400>.<label|convergence-400-para>|<pageref|auto-20>>

      <\tuple|normal>
        Normalised depth-averaged vertical velocity
        <with|mode|<quote|math>|a*<wide|w|\<bar\>>(x)> as a function of
        normalised abscissa <with|mode|<quote|math>|x/a> for (a)
        <with|mode|<quote|math>|Re=1> (b)
        <with|mode|<quote|math>|Re=400>.<label|wprofile-lateral-para>
      </tuple|<pageref|auto-21>>

      <tuple|normal|<with|mode|<quote|math>|max(u(x,z))> and
      <with|mode|<quote|math>|min(u(x,z))> as functions of
      <with|mode|<quote|math>|x> for <with|mode|<quote|math>|Re=1> (top) and
      <with|mode|<quote|math>|Re=400> (bottom).|<pageref|auto-22>>

      <tuple|normal|Position <with|mode|<quote|math>|z<rsub|null>(x)> where
      <with|mode|<quote|math>|u(x,z<rsub|null>)=0> as a function of
      <with|mode|<quote|math>|x> for <with|mode|<quote|math>|Re=1> (top) and
      <with|mode|<quote|math>|Re=400> (bottom).|<pageref|auto-23>>

      <tuple|normal|Pressure at the bottom for <with|mode|<quote|math>|Re=1>
      (top) and <with|mode|<quote|math>|Re=400> (bottom).|<pageref|auto-24>>

      <tuple|normal|Velocity field for the three-dimensional wind-driven
      lake. <with|mode|<quote|math>|a=8>, <with|mode|<quote|math>|Re=400>.
      (a) cross-section at <with|mode|<quote|math>|y=0>. (b) cross-section at
      <with|mode|<quote|math>|z=1>.<label|3D>|<pageref|auto-26>>

      <tuple|normal|Vertical profile in the center of the lake.
      <with|mode|<quote|math>|a=8>, <with|mode|<quote|math>|Re=400>.<label|3Dprofile>|<pageref|auto-27>>

      <tuple|normal|Velocity field for the wind-driven lake.
      <with|mode|<quote|math>|a=4>, <with|mode|<quote|math>|Re=400>,
      <with|mode|<quote|math>|\<alpha\><rsub|t>=1/400>.<label|vectors-strat>|<pageref|auto-29>>

      <tuple|normal|Convergence of the velocity profiles in the center of the
      lake as a function of the aspect ratio.
      <with|mode|<quote|math>|Re=400>, <with|mode|<quote|math>|\<alpha\><rsub|t>=1/400>.<label|convergence-strat>|<pageref|auto-30>>

      <tuple|normal|Convergence of the surface pressure profiles as a
      function of the aspect ratio. <with|mode|<quote|math>|Re=400>,
      <with|mode|<quote|math>|\<alpha\><rsub|t>=1/400>. The analytical
      solution is given by (<reference|alpha-strat>).<label|convergence-strat>|<pageref|auto-31>>

      <\tuple|normal>
        Convergence of the thermocline profiles as a function of the aspect
        ratio. <with|mode|<quote|math>|Re=400>,
        <with|mode|<quote|math>|\<alpha\><rsub|t>=1/400>. The analytical
        solution is given by (<reference|alphat-strat>).<label|convergence-thermocline>
      </tuple|<pageref|auto-32>>

      <tuple|normal|Error distribution <with|mode|<quote|math>|e<rsub|RMS>(x)>
      for <with|mode|<quote|math>|Re=400>,
      <with|mode|<quote|math>|\<alpha\><rsub|t>=1/400>.<label|xprofile-strat>|<pageref|auto-33>>

      <tuple|normal|Error distribution <with|mode|<quote|math>|e<rsub|RMS>(x)>
      for <with|mode|<quote|math>|Re=400>,
      <with|mode|<quote|math>|\<alpha\><rsub|t>=1/400>.<label|xprofile-lateral-strat>|<pageref|auto-34>>
    </associate>
    <\associate|toc>
      <vspace*|1fn><with|font-series|<quote|bold>|math-font-series|<quote|bold>|1<space|2spc>Constant
      density> <datoms|<macro|x|<repeat|<arg|x>|<with|font-series|medium|<with|font-size|1|<space|0.2fn>.<space|0.2fn>>>>>|<htab|5mm>>
      <no-break><pageref|auto-1><vspace|0.5fn>

      <with|par-left|<quote|1.5fn>|1.1<space|2spc>Parabolic bathymetry
      <datoms|<macro|x|<repeat|<arg|x>|<with|font-series|medium|<with|font-size|1|<space|0.2fn>.<space|0.2fn>>>>>|<htab|5mm>>
      <no-break><pageref|auto-16>>

      <with|par-left|<quote|3fn>|1.1.1<space|2spc>Three-dimensional
      paraboloidal bathymetry <datoms|<macro|x|<repeat|<arg|x>|<with|font-series|medium|<with|font-size|1|<space|0.2fn>.<space|0.2fn>>>>>|<htab|5mm>>
      <no-break><pageref|auto-25>>

      <vspace*|1fn><with|font-series|<quote|bold>|math-font-series|<quote|bold>|2<space|2spc>Stratified
      lake> <datoms|<macro|x|<repeat|<arg|x>|<with|font-series|medium|<with|font-size|1|<space|0.2fn>.<space|0.2fn>>>>>|<htab|5mm>>
      <no-break><pageref|auto-28><vspace|0.5fn>
    </associate>
  </collection>
</auxiliary>