for r in 1 2 4 8 16; do 
    gerris2D -DRATIO=$r -DRE=10. lake.gfs > /dev/null; 
    gerris2D -DRATIO=$r -DRE=400. lake.gfs > /dev/null; 
done

echo "Save vectors.eps { format = EPS }" | gfsview-batch2D end-4-10..gfs vectors.gfv
echo "Save vectors-400.eps { format = EPS }" | gfsview-batch2D end-4-400..gfs vectors.gfv

gnuplot <<EOF
set term postscript eps color lw 2 18
set output 'profile.eps'
set xlabel 'z'
set ylabel 'u'
set key top left
plot [0:1][-0.1:0.25] 0.25*x*(3.*x-2) t 'analytical', 'lake-4-10.' u (1.+\$1):2 ps 2 t 'Gerris'

set output 'convergence.eps'
plot [0:1][-0.1:0.25] 0.25*x*(3.*x-2) t 'analytical', 'lake-1-10.' u (1.+\$1):2 ps 2 t 'a = 1', 'lake-2-10.' u (1.+\$1):2 ps 2 t 'a = 2', 'lake-4-10.' u (1.+\$1):2 ps 2 t 'a = 4', 'lake-8-10.' u (1.+\$1):2 ps 2 t 'a = 8'

set output 'convergence-400.eps'
plot [0:1][-0.1:0.25] 0.25*x*(3.*x-2) t 'analytical', 'lake-1-400.' u (1.+\$1):2 ps 2 t 'a = 1', 'lake-2-400.' u (1.+\$1):2 ps 2 t 'a = 2', 'lake-4-400.' u (1.+\$1):2 ps 2 t 'a = 4', 'lake-8-400.' u (1.+\$1):2 ps 2 t 'a = 8',  'lake-16-400.' u (1.+\$1):2 ps 2 t 'a = 16'

set output 'xprofile.eps'
set xlabel 'x'
set ylabel 'RMS Error'
plot 'ep-1-10.' w lp t 'a=1', 'ep-2-10.' w lp t 'a=2', 'ep-4-10.' w lp t 'a=4', 'ep-8-10.' w lp t 'a=8'

set output 'xprofile-400.eps'
set key top right
plot 'ep-1-400.' w lp t 'a=1', 'ep-2-400.' w lp t 'a=2', 'ep-4-400.' w lp t 'a=4', 'ep-8-400.' w lp t 'a=8', 'ep-16-400.' w lp t 'a=16'

set output 'xprofile-lateral.eps'
set xlabel '|x|-a/2'
set key top left
plot 'ep-1-10.' u (abs(\$1)-0.5):2 w lp t 'a=1', 'ep-2-10.' u (abs(\$1)-1.):2 w lp t 'a=2', 'ep-4-10.' u (abs(\$1)-2.):2 w lp t 'a=4', 'ep-8-10.'  u (abs(\$1)-4.):2 w lp t 'a=8'

set output 'xprofile-lateral-400.eps'
plot 'ep-1-400.' u (abs(\$1)-0.5):2 w lp t 'a=1', 'ep-2-400.' u (abs(\$1)-1.):2 w lp t 'a=2', 'ep-4-400.' u (abs(\$1)-2.):2 w lp t 'a=4', 'ep-8-400.'  u (abs(\$1)-4.):2 w lp t 'a=8', 'ep-16-400.'  u (abs(\$1)-8.):2 w lp t 'a=16'

set output 'wprofile.eps'
set key top right
set xlabel 'x'
set ylabel 'Depth-averaged vertical velocity'
plot 'ep-1-10.' u 1:3 w lp t 'a=1', 'ep-2-10.' u 1:3 w lp t 'a=2', 'ep-4-10.' u 1:3 w lp t 'a=4', 'ep-8-10.' u 1:3 w lp t 'a=8'

set output 'wprofile-400.eps'
set key bottom left
plot 'ep-1-400.' u 1:3 w lp t 'a=1', 'ep-2-400.' u 1:3 w lp t 'a=2', 'ep-4-400.' u 1:3 w lp t 'a=4', 'ep-8-400.' u 1:3 w lp t 'a=8', 'ep-16-400.' u 1:3 w lp t 'a=16'

set output 'wprofile-lateral.eps'
set xlabel '|x|-a/2'
set key top left
plot 'ep-1-10.' u (abs(\$1)-0.5):3 w lp t 'a=1', 'ep-2-10.' u (abs(\$1)-1.):3 w lp t 'a=2', 'ep-4-10.' u (abs(\$1)-2.):3 w lp t 'a=4', 'ep-8-10.' u (abs(\$1)-4.):3 w lp t 'a=8'

set output 'wprofile-lateral-400.eps'
set key bottom left
plot 'ep-1-400.' u (abs(\$1)-0.5):3 w lp t 'a=1', 'ep-2-400.' u (abs(\$1)-1.):3 w lp t 'a=2', 'ep-4-400.' u (abs(\$1)-2.):3 w lp t 'a=4', 'ep-8-400.'  u (abs(\$1)-4.):3 w lp t 'a=8', 'ep-16-400.'  u (abs(\$1)-8.):3 w lp t 'a=16'

EOF
