lowRe=1.

for r in 1 2 4 8 16; do 
    echo $r-$lowRe
    gerris2D -DRATIO=$r -DRE=$lowRe -DDTMAX=1e-2 -DDUMIN=1e-2 lake.gfs 2> log-$r-$lowRe > /dev/null; 
    echo $r-400.
    gerris2D -DRATIO=$r -DRE=400. -DDTMAX=0.1 -DDUMIN=5e-4 lake.gfs 2> log-$r-400. > /dev/null; 
done

echo "Save vectors.eps { format = EPS }" | gfsview-batch2D end-4-$lowRe.gfs vectors.gfv
echo "Save vectors-400.eps { format = EPS }" | gfsview-batch2D end-4-400..gfs vectors.gfv

gnuplot <<EOF
set term postscript eps color lw 2 18
set output 'pressure-profile.eps'
set xlabel 'x'
set ylabel 'Pressure'
set key top left
plot 3/2.*1./$lowRe*x t 'analytical', 'end-4-$lowRe.txt' u 1:4 ps 2 t 'Gerris'

set output 'profile.eps'
set xlabel 'z'
set ylabel 'u'
set key top left
plot [0:1][-0.1:0.25] 0.25*x*(3.*x-2) t 'analytical', 'lake-4-$lowRe' u (1.+\$1):2 ps 2 t 'Gerris'

set output 'convergence.eps'
plot [0:1][-0.1:0.25] 0.25*x*(3.*x-2) t 'analytical', 'lake-1-$lowRe' u (1.+\$1):2 ps 1 t 'a = 1', 'lake-2-$lowRe' u (1.+\$1):2 ps 1 t 'a = 2', 'lake-4-$lowRe' u (1.+\$1):2 ps 1 t 'a = 4', 'lake-8-$lowRe' u (1.+\$1):2 ps 1 t 'a = 8'

set output 'convergence-400.eps'
plot [0:1][-0.1:0.25] 0.25*x*(3.*x-2) t 'analytical', 'lake-1-400.' u (1.+\$1):2 ps 1 t 'a = 1', 'lake-2-400.' u (1.+\$1):2 ps 1 t 'a = 2', 'lake-4-400.' u (1.+\$1):2 ps 1 t 'a = 4', 'lake-8-400.' u (1.+\$1):2 ps 1 t 'a = 8',  'lake-16-400.' u (1.+\$1):2 ps 1 lt 7 t 'a = 16'

set output 'convergence-pressure-400.eps'
set xlabel 'x'
set ylabel 'Pressure'
plot 3/2.*1./400.*x t 'analytical', 'end-1-400..txt' u 1:4 ps 1 t 'a = 1', 'end-2-400..txt' u 1:4 ps 1 t 'a = 2', 'end-4-400..txt' u 1:4 ps 1 t 'a = 4', 'end-8-400..txt' u 1:4 ps 1 t 'a = 8',  'end-16-400..txt' u 1:4 ps 1 lt 7 t 'a = 16'

set output 'xprofile.eps'
set xlabel 'x'
set ylabel 'RMS Error'
plot 'ep-1-$lowRe' w lp t 'a=1', 'ep-2-$lowRe' w lp t 'a=2', 'ep-4-$lowRe' w lp t 'a=4', 'ep-8-$lowRe' w lp t 'a=8'

set output 'xprofile-400.eps'
set key top right
plot 'ep-1-400.' w lp t 'a=1', 'ep-2-400.' w lp t 'a=2', 'ep-4-400.' w lp t 'a=4', 'ep-8-400.' w lp t 'a=8', 'ep-16-400.' w lp t 'a=16'

set output 'xprofile-lateral.eps'
set xlabel '|x|-a/2'
set key top left
plot 'ep-1-$lowRe' u (abs(\$1)-0.5):2 w lp t 'a=1', 'ep-2-$lowRe' u (abs(\$1)-1.):2 w lp t 'a=2', 'ep-4-$lowRe' u (abs(\$1)-2.):2 w lp t 'a=4', 'ep-8-$lowRe'  u (abs(\$1)-4.):2 w lp t 'a=8'

set output 'xprofile-lateral-400.eps'
plot 'ep-1-400.' u (abs(\$1)-0.5):2 w lp t 'a=1', 'ep-2-400.' u (abs(\$1)-1.):2 w lp t 'a=2', 'ep-4-400.' u (abs(\$1)-2.):2 w lp t 'a=4', 'ep-8-400.'  u (abs(\$1)-4.):2 w lp t 'a=8', 'ep-16-400.'  u (abs(\$1)-8.):2 w lp t 'a=16'

set output 'wprofile.eps'
set key top right
set xlabel 'x'
set ylabel 'Depth-averaged vertical velocity'
plot 'ep-1-$lowRe' u 1:3 w lp t 'a=1', 'ep-2-$lowRe' u 1:3 w lp t 'a=2', 'ep-4-$lowRe' u 1:3 w lp t 'a=4', 'ep-8-$lowRe' u 1:3 w lp t 'a=8'

set output 'wprofile-400.eps'
set key bottom left
plot 'ep-1-400.' u 1:3 w lp t 'a=1', 'ep-2-400.' u 1:3 w lp t 'a=2', 'ep-4-400.' u 1:3 w lp t 'a=4', 'ep-8-400.' u 1:3 w lp t 'a=8', 'ep-16-400.' u 1:3 w lp t 'a=16'

set output 'wprofile-lateral.eps'
set xlabel '|x|-a/2'
set key top left
plot 'ep-1-$lowRe' u (abs(\$1)-0.5):3 w lp t 'a=1', 'ep-2-$lowRe' u (abs(\$1)-1.):3 w lp t 'a=2', 'ep-4-$lowRe' u (abs(\$1)-2.):3 w lp t 'a=4', 'ep-8-$lowRe' u (abs(\$1)-4.):3 w lp t 'a=8'

set output 'wprofile-lateral-400.eps'
set key bottom left
plot 'ep-1-400.' u (abs(\$1)-0.5):3 w lp t 'a=1', 'ep-2-400.' u (abs(\$1)-1.):3 w lp t 'a=2', 'ep-4-400.' u (abs(\$1)-2.):3 w lp t 'a=4', 'ep-8-400.'  u (abs(\$1)-4.):3 w lp t 'a=8', 'ep-16-400.'  u (abs(\$1)-8.):3 w lp t 'a=16'

EOF
