lowRe=1.

for r in 1 2 4 8 16; do
    echo $r-$lowRe
    gerris2D -DRATIO1=`echo $r | awk '{print $1/8.}'` -DRATIO=$r -DRE=$lowRe -DDTMAX=1e-2 -DDUMIN=1e-2 lake.gfs 2> log-$r-$lowRe > /dev/null; 
    echo $r-400.
    gerris2D -DRATIO1=`echo $r | awk '{print $1/8.}'` -DRATIO=$r -DRE=400. -DDTMAX=0.1 -DDUMIN=5e-5 lake.gfs 2> log-$r-400. > /dev/null; 
done

r=4
for re in 2 8 32 128 512 1000; do
    echo $r-$re
    gerris2D -DRATIO1=`echo $r | awk '{print $1/8.}'` -DRATIO=$r -DRE=$re -DDTMAX=0.1 -DDUMIN=5e-5 lake.gfs 2> log-$r-$re > /dev/null; 
done

echo "Save vectors.eps { format = EPS }" | gfsview-batch2D end-4-$lowRe.gfs vectors.gfv
echo "Save vectors-400.eps { format = EPS }" | gfsview-batch2D end-4-400..gfs vectors.gfv

gnuplot <<EOF
set term postscript eps color lw 2 18

set output 'profile.eps'
set xlabel 'z'
set ylabel 'u'
set key top left
plot [0:1][-0.1:0.25] 0.25*x*(3.*x-2) t 'analytical', 'lake-4-$lowRe' u (1.+\$1):2 ps 2 t 'Gerris'

set output 'convergence.eps'
plot [0:1][-0.1:0.25] 0.25*x*(3.*x-2) t 'analytical', 'lake-1-$lowRe' u (1.+\$1):2 ps 1 t 'a = 1', 'lake-2-$lowRe' u (1.+\$1):2 ps 1 t 'a = 2', 'lake-4-$lowRe' u (1.+\$1):2 ps 1 t 'a = 4', 'lake-8-$lowRe' u (1.+\$1):2 ps 1 t 'a = 8'

set output 'convergence-400.eps'
plot [0:1][-0.1:0.25] 0.25*x*(3.*x-2) t 'analytical', 'lake-1-400.' u (1.+\$1):2 ps 1 t 'a = 1', 'lake-2-400.' u (1.+\$1):2 ps 1 t 'a = 2', 'lake-4-400.' u (1.+\$1):2 ps 1 t 'a = 4', 'lake-8-400.' u (1.+\$1):2 ps 1 t 'a = 8',  'lake-16-400.' u (1.+\$1):2 ps 1 lt 7 t 'a = 16'

set output 'xprofile.eps'
set xlabel 'x'
set ylabel 'RMS Error'
plot 'ep-1-$lowRe' u 1:(\$2/0.091) w l t 'a=1', 'ep-2-$lowRe' u 1:(\$2/0.091) w l t 'a=2', 'ep-4-$lowRe' u 1:(\$2/0.091) w l t 'a=4', 'ep-8-$lowRe' u 1:(\$2/0.091) w l t 'a=8', 'ep-16-$lowRe' u 1:(\$2/0.091) w l t 'a=16'

set output 'xprofile-400.eps'
set key top right
plot 'ep-1-400.' u 1:(\$2/0.091) w l t 'a=1', 'ep-2-400.' u 1:(\$2/0.091) w l t 'a=2', 'ep-4-400.' u 1:(\$2/0.091) w l t 'a=4', 'ep-8-400.' u 1:(\$2/0.091) w l t 'a=8', 'ep-16-400.' u 1:(\$2/0.091) w l t 'a=16'

set output 'xprofile-lateral.eps'
set xlabel '|x|-a/2'
set key top left
plot [-4:0]'ep-1-$lowRe' u (abs(\$1)-0.5):(\$2/0.091) w l t 'a=1', 'ep-2-$lowRe' u (abs(\$1)-1.):(\$2/0.091) w l t 'a=2', 'ep-4-$lowRe' u (abs(\$1)-2.):(\$2/0.091) w l t 'a=4', 'ep-8-$lowRe'  u (abs(\$1)-4.):(\$2/0.091) w l t 'a=8', 'ep-16-$lowRe'  u (abs(\$1)-8.):(\$2/0.091) w l t 'a=16'

set output 'xprofile-lateral-400.eps'
plot [-4:0]'ep-1-400.' u (abs(\$1)-0.5):(\$2/0.091) w l t 'a=1', 'ep-2-400.' u (abs(\$1)-1.):(\$2/0.091) w l t 'a=2', 'ep-4-400.' u (abs(\$1)-2.):(\$2/0.091) w l t 'a=4', 'ep-8-400.'  u (abs(\$1)-4.):(\$2/0.091) w l t 'a=8', 'ep-16-400.'  u (abs(\$1)-8.):(\$2/0.091) w l t 'a=16'

set output 'wprofile.eps'
set key top right
set xlabel 'x'
set ylabel 'Depth-averaged vertical velocity'
plot 'ep-1-$lowRe' u 1:3 w l t 'a=1', 'ep-2-$lowRe' u 1:3 w l t 'a=2', 'ep-4-$lowRe' u 1:3 w l t 'a=4', 'ep-8-$lowRe' u 1:3 w l t 'a=8'

set output 'wprofile-400.eps'
set key bottom left
plot 'ep-1-400.' u 1:3 w l t 'a=1', 'ep-2-400.' u 1:3 w l t 'a=2', 'ep-4-400.' u 1:3 w l t 'a=4', 'ep-8-400.' u 1:3 w l t 'a=8', 'ep-16-400.' u 1:3 w l t 'a=16'

set output 'wprofile-lateral.eps'
set xlabel '|x|-a/2'
set key top left
plot [-2:0]'ep-1-$lowRe' u (abs(\$1)-0.5):3 w l t 'a=1', 'ep-2-$lowRe' u (abs(\$1)-1.):3 w l t 'a=2', 'ep-4-$lowRe' u (abs(\$1)-2.):3 w l t 'a=4', 'ep-8-$lowRe' u (abs(\$1)-4.):3 w l t 'a=8', 'ep-16-$lowRe'  u (abs(\$1)-8.):3 w l t 'a=16'

set output 'wprofile-lateral-400.eps'
set key bottom left
plot [-4:0]'ep-1-400.' u (abs(\$1)-0.5):3 w l t 'a=1', 'ep-2-400.' u (abs(\$1)-1.):3 w l t 'a=2', 'ep-4-400.' u (abs(\$1)-2.):3 w l t 'a=4', 'ep-8-400.'  u (abs(\$1)-4.):3 w l t 'a=8', 'ep-16-400.'  u (abs(\$1)-8.):3 w l t 'a=16'

EOF

for r in 1 2 4 8 16; do
    for re in $lowRe 400.; do
	gawk '{ if ($2 == -0.015625) print $1,-1e-6,0;}' < end-$r-$re.txt > location
	gerris2D -e "OutputLocation stderr location" end-$r-$re.gfs > /dev/null 2> top
	gawk '{ for (i = 2; i <= NF; i++) printf ("%s ", $i); printf ("\n");}' < top > top1
	cat end-$r-$re.txt top1 | gawk -v ratio=$r '{
          if ($1 != "#") {
            a[$1] = $1
            u[$1] += $6
            if ($6 > umax[$1])
              umax[$1] = $6;
            if ($6 < umin[$1])
              umin[$1] = $6;
            n[$1]++
          }
        } END {
          for (i in a)
            print i/ratio,umin[i],u[i]/n[i],umax[i];
        }' | sort -n -k 1,2 > u-$r-$re
    done
done

gnuplot <<EOF
set term postscript eps color lw 2 18 enhanced
set output 'uminmax-1.eps'
set xlabel 'x/a'
set ylabel 'max_z(u(x,z)),min_z(u(x,z))'
set key center center

plot [-0.5:0.5][:0.26]\
     'u-1-1.' u 1:2 w l t 'a=1' lt 1, 'u-1-1.' u 1:4 w l t '' lt 1, \
     'u-2-1.' u 1:2 w l t 'a=2' lt 2, 'u-2-1.' u 1:4 w l t '' lt 2, \
     'u-4-1.' u 1:2 w l t 'a=4' lt 3, 'u-4-1.' u 1:4 w l t '' lt 3, \
     'u-8-1.' u 1:2 w l t 'a=8' lt 4, 'u-8-1.' u 1:4 w l t '' lt 4, \
     'u-16-1.' u 1:2 w l t 'a=16' lt 5, 'u-16-1.' u 1:4 w l t '' lt 5

set output 'uminmax-400.eps'
plot 'u-1-400.' u 1:2 w l t 'a=1' lt 1, 'u-1-400.' u 1:4 w l t '' lt 1, \
     'u-2-400.' u 1:2 w l t 'a=2' lt 2, 'u-2-400.' u 1:4 w l t '' lt 2, \
     'u-4-400.' u 1:2 w l t 'a=4' lt 3, 'u-4-400.' u 1:4 w l t '' lt 3, \
     'u-8-400.' u 1:2 w l t 'a=8' lt 4, 'u-8-400.' u 1:4 w l t '' lt 4, \
     'u-16-400.' u 1:2 w l t 'a=16' lt 5, 'u-16-400.' u 1:4 w l t '' lt 5
EOF

for r in 1 2 4 8 16; do
    for re in $lowRe 400.; do
	echo "Save stdout { format = Gnuplot }" | gfsview-batch2D end-$r-$re.gfs znull.gfv | awk -v ratio=$r '{ if (NF == 3) print $1/ratio,$2; else print $0;}' > znull-$r-$re
    done
done

gnuplot <<EOF
set term postscript eps color lw 2 18 enhanced
set output 'znull-1.eps'
set xlabel 'x/a'
set ylabel 'z where u(x,z)=0'
set key top center

plot [-0.498:0.498][-0.34:-0.24]\
     'znull-1-1.' u 1:2 w l t 'a=1' lt 1,\
     'znull-2-1.' u 1:2 w l t 'a=2' lt 2,\
     'znull-4-1.' u 1:2 w l t 'a=4' lt 3,\
     'znull-8-1.' u 1:2 w l t 'a=8' lt 4,\
     'znull-16-1.' u 1:2 w l t 'a=16' lt 5

set key top right
set output 'znull-400.eps'
plot [-0.498:0.498][-0.45:-0.12]\
     'znull-1-400.' u 1:2 w l t 'a=1' lt 1,\
     'znull-2-400.' u 1:2 w l t 'a=2' lt 2,\
     'znull-4-400.' u 1:2 w l t 'a=4' lt 3,\
     'znull-8-400.' u 1:2 w l t 'a=8' lt 4,\
     'znull-16-400.' u 1:2 w l t 'a=16' lt 5
EOF

for r in 1 2 4 8 16; do
    for re in $lowRe 400.; do
	gawk '{ if ($2 == -0.015625) print $1,-1+1e-6,0;}' < end-$r-$re.txt > location
	gerris2D -e "OutputLocation stderr location" end-$r-$re.gfs > /dev/null 2> pb-$r-$re
    done
done

gnuplot <<EOF
set term postscript eps color lw 2 18 enhanced
set output 'convergence-pressure-400.eps'
set xlabel 'x'
set ylabel 'Pressure'
set key top left

plot 3/2.*1./400.*x t 'analytical' lt 0, 'pb-1-400.' u 2:(\$5-0.00367) w l t 'a = 1' lt 1, 'pb-2-400.' u 2:(\$5-0.00308) w l t 'a = 2' lt 2, 'pb-4-400.' u 2:(\$5-0.0045) w l t 'a = 4' lt 3, 'pb-8-400.' u 2:(\$5-0.00846) w l t 'a = 8' lt 4, 'pb-16-400.' u 2:(\$5-0.0209) w l lt 5 t 'a = 16'

set output 'convergence-pressure-1.eps'
plot 3/2.*x t 'analytical' lt 0, 'pb-1-1.' u 2:(\$5-1.982) w l t 'a = 1' lt 1, 'pb-2-1.' u 2:(\$5-2.664) w l t 'a = 2' lt 2, 'pb-4-1.' u 2:(\$5-4.086) w l t 'a = 4' lt 3, 'pb-8-1.' u 2:(\$5-6.9849) w l t 'a = 8' lt 4, 'pb-16-1.' u 2:(\$5-12.854) w l lt 5 t 'a = 16'
EOF

r=4
for re in 1. 2 8 32 128 400. 512 1000; do
    awk -v ratio=$r -v re=$re 'BEGIN { n = 0; min = 1e6; } {
      if ($3 < min)
        min = $3;
      x[n] = $1;
      w[n++] = $3;
    } END {
      for (i = 0; i < n; i++)
        if (w[i]/min > 0.1) {          
          print re,ratio/2.-(x[i-1] + (0.1 - w[i-1]/min)*min*(x[i] - x[i-1])/(w[i] - w[i-1]));
          exit (0);
        }
      exit (1);
    }' < ep-$r-$re
done > re

gnuplot <<EOF
set term postscript eps color lw 2 18 enhanced
set output 're.eps'
set xlabel 'Re'
set ylabel 'Downwelling width'
set key top right

set logscale x
plot 're' w lp t '256x32', 'finer-re/re' w lp t '512x64'
EOF
