lowRe=1.

for r in 1 2 4 8 16; do 
    echo $r-$lowRe
    gerris2D -DRATIO=$r -DRE=$lowRe -DDTMAX=1e-2 -DDUMIN=1e-2 lake.gfs 2> log-$r-$lowRe > /dev/null; 
    echo $r-400.
    gerris2D -DRATIO=$r -DRE=400. -DDTMAX=0.1 -DDUMIN=5e-4 lake.gfs 2> log-$r-400. > /dev/null; 
done

echo "Save vectors.eps { format = EPS }" | gfsview-batch2D end-4-$lowRe.gfs vectors.gfv
echo "Save vectors-400.eps { format = EPS }" | gfsview-batch2D end-4-400..gfs vectors.gfv

gnuplot <<EOF
set term postscript eps color lw 2 18
set output 'profile.eps'
set xlabel 'z'
set ylabel 'u'
set key top left
plot [0:1][-0.1:0.25] 0.25*x*(3.*x-2) t 'analytical', 'lake-4-$lowRe' u (1.+\$1):2 ps 2 t 'Gerris'

set output 'convergence.eps'
plot [0:1][-0.1:0.25] 0.25*x*(3.*x-2) t 'analytical', 'lake-1-$lowRe' u (1.+\$1):2 ps 2 t 'a = 1', 'lake-2-$lowRe' u (1.+\$1):2 ps 2 t 'a = 2', 'lake-4-$lowRe' u (1.+\$1):2 ps 2 t 'a = 4', 'lake-8-$lowRe' u (1.+\$1):2 ps 2 t 'a = 8'

set output 'convergence-400.eps'
plot [0:1][-0.1:0.25] 0.25*x*(3.*x-2) t 'analytical', 'lake-1-400.' u (1.+\$1):2 ps 2 t 'a = 1', 'lake-2-400.' u (1.+\$1):2 ps 2 t 'a = 2', 'lake-4-400.' u (1.+\$1):2 ps 2 t 'a = 4', 'lake-8-400.' u (1.+\$1):2 ps 2 t 'a = 8',  'lake-16-400.' u (1.+\$1):2 ps 2 t 'a = 16', 'lake-32-400.' u (1.+\$1):2 ps 2 t 'a = 32'

set output 'xprofile.eps'
set xlabel 'x'
set ylabel 'RMS Error'
plot 'ep-1-$lowRe' w lp t 'a=1', 'ep-2-$lowRe' w lp t 'a=2', 'ep-4-$lowRe' w lp t 'a=4', 'ep-8-$lowRe' w lp t 'a=8'

set output 'xprofile-400.eps'
set key top center
plot 'ep-1-400.' w lp t 'a=1', 'ep-2-400.' w lp t 'a=2', 'ep-4-400.' w lp t 'a=4', 'ep-8-400.' w lp t 'a=8', 'ep-16-400.' w lp t 'a=16', 'ep-32-400.' w lp t 'a=32'

set output 'xprofile-lateral.eps'
set xlabel 'x/a'
plot 'ep-1-$lowRe' u (\$1):2 w lp t 'a=1', 'ep-2-$lowRe' u (\$1/2.):2 w lp t 'a=2', 'ep-4-$lowRe' u (\$1/4.):2 w lp t 'a=4', 'ep-8-$lowRe'  u (\$1/8.):2 w lp t 'a=8'

set output 'xprofile-lateral-400.eps'
plot 'ep-1-400.' u (\$1):2 w lp t 'a=1', 'ep-2-400.' u (\$1/2.):2 w lp t 'a=2', 'ep-4-400.' u (\$1/4.):2 w lp t 'a=4', 'ep-8-400.'  u (\$1/8.):2 w lp t 'a=8', 'ep-16-400.'  u (\$1/16.):2 w lp t 'a=16', 'ep-32-400.'  u (\$1/32.):2 w lp t 'a=32'

set output 'wprofile.eps'
set key top right
set xlabel 'x'
set ylabel 'Depth-averaged vertical velocity'
plot 'ep-1-$lowRe' u 1:3 w lp t 'a=1', 'ep-2-$lowRe' u 1:3 w lp t 'a=2', 'ep-4-$lowRe' u 1:3 w lp t 'a=4', 'ep-8-$lowRe' u 1:3 w lp t 'a=8'

set output 'wprofile-400.eps'
set key bottom left
plot 'ep-1-400.' u 1:3 w lp t 'a=1', 'ep-2-400.' u 1:3 w lp t 'a=2', 'ep-4-400.' u 1:3 w lp t 'a=4', 'ep-8-400.' u 1:3 w lp t 'a=8', 'ep-16-400.' u 1:3 w lp t 'a=16', 'ep-32-400.' u 1:3 w lp t 'a=32'

set output 'wprofile-lateral.eps'
set xlabel 'x/a'
set ylabel 'Normalised depth-averaged vertical velocity'
set key top left
plot 'ep-1-$lowRe' u (\$1):3 w lp t 'a=1', 'ep-2-$lowRe' u (\$1/2.):(2.*\$3) w lp t 'a=2', 'ep-4-$lowRe' u (\$1/4.):(4.*\$3) w lp t 'a=4', 'ep-8-$lowRe' u (\$1/8.):(8.*\$3) w lp t 'a=8'

set output 'wprofile-lateral-400.eps'
set key bottom left
plot 'ep-1-400.' u (\$1):3 w lp t 'a=1', 'ep-2-400.' u (\$1/2.):(2.*\$3) w lp t 'a=2', 'ep-4-400.' u (\$1/4.):(4.*\$3) w lp t 'a=4', 'ep-8-400.'  u (\$1/8.):(8.*\$3) w lp t 'a=8', 'ep-16-400.'  u (\$1/16.):(16.*\$3) w lp t 'a=16', 'ep-32-400.' u (\$1/32.):(32.*\$3) w lp t 'a=32'

EOF
