set term postscript eps color lw 2 18 enhanced

set output 'profile.eps'
set xlabel 'z'
set ylabel 'u'
set key top left
plot [0:1][-0.1:0.25] 0.25*x*(3.*x-2) t 'analytical', 'lake-4-1.' u (1.+$1):2 ps 2 t 'Gerris'

set output 'convergence.eps'
plot [0:1][-0.1:0.25] 0.25*x*(3.*x-2) t 'analytical', 'lake-1-1.' u (1.+$1):2 ps 1 t 'a = 1', 'lake-2-1.' u (1.+$1):2 ps 1 t 'a = 2', 'lake-4-1.' u (1.+$1):2 ps 1 t 'a = 4', 'lake-8-1.' u (1.+$1):2 ps 1 t 'a = 8'

set output 'convergence-400.eps'
plot [0:1][-0.1:0.25] 0.25*x*(3.*x-2) t 'analytical', 'lake-1-400.' u (1.+$1):2 ps 1 t 'a = 1', 'lake-2-400.' u (1.+$1):2 ps 1 t 'a = 2', 'lake-4-400.' u (1.+$1):2 ps 1 t 'a = 4', 'lake-8-400.' u (1.+$1):2 ps 1 t 'a = 8',  'lake-16-400.' u (1.+$1):2 ps 1 lt 7 t 'a = 16'

set output 'wprofile-lateral.eps'
set xlabel 'x/a'
set ylabel 'Normalised depth-averaged vertical velocity'
set key top right
plot 'v-1-1.' w l t 'a=1', 'v-2-1.' w l t 'a=2', 'v-4-1.' w l t 'a=4', 'v-8-1.' w l t 'a=8', 'v-16-1.' w l t 'a=16'

set output 'wprofile-lateral-400.eps'
set key bottom left
plot 'v-1-400.' w l t 'a=1', 'v-2-400.' w l t 'a=2', 'v-4-400.' w l t 'a=4', 'v-8-400.' w l t 'a=8', 'v-16-400.' w l t 'a=16'

set output 'uminmax-1.eps'
set xlabel 'x/a'
set ylabel 'max_z(u(x,z)),min_z(u(x,z))'
set key top left

plot [-0.5:0.5][:0.26]\
     'u-1-1.' u 1:2 w l t 'a=1' lt 1, 'u-1-1.' u 1:4 w l t '' lt 1, \
     'u-2-1.' u 1:2 w l t 'a=2' lt 2, 'u-2-1.' u 1:4 w l t '' lt 2, \
     'u-4-1.' u 1:2 w l t 'a=4' lt 3, 'u-4-1.' u 1:4 w l t '' lt 3, \
     'u-8-1.' u 1:2 w l t 'a=8' lt 4, 'u-8-1.' u 1:4 w l t '' lt 4, \
     'u-16-1.' u 1:2 w l t 'a=16' lt 5, 'u-16-1.' u 1:4 w l t '' lt 5

set output 'uminmax-400.eps'
plot 'u-1-400.' u 1:2 w l t 'a=1' lt 1, 'u-1-400.' u 1:4 w l t '' lt 1, \
     'u-2-400.' u 1:2 w l t 'a=2' lt 2, 'u-2-400.' u 1:4 w l t '' lt 2, \
     'u-4-400.' u 1:2 w l t 'a=4' lt 3, 'u-4-400.' u 1:4 w l t '' lt 3, \
     'u-8-400.' u 1:2 w l t 'a=8' lt 4, 'u-8-400.' u 1:4 w l t '' lt 4, \
     'u-16-400.' u 1:2 w l t 'a=16' lt 5, 'u-16-400.' u 1:4 w l t '' lt 5

set output 'znull-1.eps'
set xlabel 'x/a'
set ylabel 'z where u(x,z)=0'
set key top center

plot [-0.448:0.498][-0.35:0]\
     'znull-1-1.' u 1:2 w l t 'a=1' lt 1,\
     'znull-2-1.' u 1:2 w l t 'a=2' lt 2,\
     'znull-4-1.' u 1:2 w l t 'a=4' lt 3,\
     'znull-8-1.' u 1:2 w l t 'a=8' lt 4,\
     'znull-16-1.' u 1:2 w l t 'a=16' lt 5

set key top right
set output 'znull-400.eps'
plot [-0.498:0.498][-0.35:0]\
     'znull-1-400.' u 1:2 w l t 'a=1' lt 1,\
     'znull-2-400.' u 1:2 w l t 'a=2' lt 2,\
     'znull-4-400.' u 1:2 w l t 'a=4' lt 3,\
     'znull-8-400.' u 1:2 w l t 'a=8' lt 4,\
     'znull-16-400.' u 1:2 w l t 'a=16' lt 5

set output 'convergence-pressure-400.eps'
set xlabel 'x'
set ylabel 'Pressure'
set key top left

plot 3/2.*1./400.*x t 'analytical' lt 0, 'pb-1-400.' u 1:($2-0.0063) w l t 'a = 1' lt 1, 'pb-2-400.' u 1:($2-0.0071) w l t 'a = 2' lt 2, 'pb-4-400.' u 1:($2-0.01) w l t 'a = 4' lt 3, 'pb-8-400.' u 1:($2-0.02) w l t 'a = 8' lt 4, 'pb-16-400.' u 1:($2-0.044) w l lt 5 t 'a = 16'

set output 'convergence-pressure-1.eps'
plot 3/2.*x t 'analytical' lt 0, 'pb-1-1.' u 1:($2-2.83) w l t 'a = 1' lt 1, 'pb-2-1.' u 1:($2-3.94) w l t 'a = 2' lt 2, 'pb-4-1.' u 1:($2-6.23) w l t 'a = 4' lt 3, 'pb-8-1.' u 1:($2-11.42) w l t 'a = 8' lt 4, 'pb-16-1.' u 1:($2-22.09) w l lt 5 t 'a = 16'
