lowRe=1.

for r in 1 2 4 8 16; do
    echo $r-$lowRe
    gerris2D -DRATIO1=`echo $r | awk '{print $1/8.}'` -DRATIO=$r -DRE=$lowRe -DDTMAX=1e-2 -DDUMIN=1e-2 lake.gfs 2> log-$r-$lowRe > /dev/null; 
    echo $r-400.
    gerris2D -DRATIO1=`echo $r | awk '{print $1/8.}'` -DRATIO=$r -DRE=400. -DDTMAX=0.1 -DDUMIN=5e-5 lake.gfs 2> log-$r-400. > /dev/null; 
done

r=4
for re in 2 8 32 128 512 1000; do
    echo $r-$re
    gerris2D -DRATIO1=`echo $r | awk '{print $1/8.}'` -DRATIO=$r -DRE=$re -DDTMAX=0.1 -DDUMIN=5e-5 lake.gfs 2> log-$r-$re > /dev/null; 
done

echo "Save vectors.eps { format = EPS }" | gfsview-batch2D end-4-$lowRe.gfs vectors.gfv
echo "Save vectors-400.eps { format = EPS }" | gfsview-batch2D end-4-400..gfs vectors.gfv

for r in 1 2 4 8 16; do
    for re in $lowRe 400.; do
	gerris2D -e "Init {} { Fraction = A Rx = rx }" -e "OutputSimulation end-$r-$re.txt { format = text }" end-$r-$re.gfs > /dev/null
	gawk -v ratio=$r '{
          if ($1 != "#") {
            a[$11] = $11
            v[$11] += $7*$10
            n[$11] += $10
          }
        } END {
          for (i in a)
            print i/8.,v[i]/n[i]*ratio;
        }' < end-$r-$re.txt | sort -n -k 1,2 > v-$r-$re
    done
done

gnuplot <<EOF
set term postscript eps color lw 2 18

set output 'profile.eps'
set xlabel 'z'
set ylabel 'u'
set key top left
plot [0:1][-0.1:0.25] 0.25*x*(3.*x-2) t 'analytical', 'lake-4-$lowRe' u (1.+\$1):2 ps 2 t 'Gerris'

set output 'convergence.eps'
plot [0:1][-0.1:0.25] 0.25*x*(3.*x-2) t 'analytical', 'lake-1-$lowRe' u (1.+\$1):2 ps 1 t 'a = 1', 'lake-2-$lowRe' u (1.+\$1):2 ps 1 t 'a = 2', 'lake-4-$lowRe' u (1.+\$1):2 ps 1 t 'a = 4', 'lake-8-$lowRe' u (1.+\$1):2 ps 1 t 'a = 8'

set output 'convergence-400.eps'
plot [0:1][-0.1:0.25] 0.25*x*(3.*x-2) t 'analytical', 'lake-1-400.' u (1.+\$1):2 ps 1 t 'a = 1', 'lake-2-400.' u (1.+\$1):2 ps 1 t 'a = 2', 'lake-4-400.' u (1.+\$1):2 ps 1 t 'a = 4', 'lake-8-400.' u (1.+\$1):2 ps 1 t 'a = 8',  'lake-16-400.' u (1.+\$1):2 ps 1 lt 7 t 'a = 16'

set output 'wprofile-lateral.eps'
set xlabel 'x/a'
set ylabel 'Normalised depth-averaged vertical velocity'
set key top right
plot 'v-1-$lowRe' w l t 'a=1', 'v-2-$lowRe' w l t 'a=2', 'v-4-$lowRe' w l t 'a=4', 'v-8-$lowRe' w l t 'a=8', 'v-16-$lowRe' w l t 'a=16'

set output 'wprofile-lateral-400.eps'
set key bottom left
plot 'v-1-400.' w l t 'a=1', 'v-2-400.' w l t 'a=2', 'v-4-400.' w l t 'a=4', 'v-8-400.' w l t 'a=8', 'v-16-400.' w l t 'a=16'

EOF

for r in 1 2 4 8 16; do
    for re in $lowRe 400.; do
	gawk '{ if ($2 == -0.015625) print $1,-1e-6,0;}' < end-$r-$re.txt > location
	gerris2D -e "OutputLocation stderr location" end-$r-$re.gfs > /dev/null 2> top
	gawk '{ for (i = 2; i <= NF; i++) printf ("%s ", $i); printf ("\n");}' < top > top1
	cat end-$r-$re.txt top1 | gawk -v ratio=$r '{
          if ($1 != "#" && $10 == 1.) {
            a[$1] = $1
            u[$1] += $6
            if ($6 > umax[$1])
              umax[$1] = $6;
            if ($6 < umin[$1])
              umin[$1] = $6;
            n[$1]++
          }
        } END {
          for (i in a)
            print i/ratio,umin[i],u[i]/n[i],umax[i];
        }' | sort -n -k 1,2 > u-$r-$re
    done
done

gnuplot <<EOF
set term postscript eps color lw 2 18 enhanced
set output 'uminmax-1.eps'
set xlabel 'x/a'
set ylabel 'max_z(u(x,z)),min_z(u(x,z))'
set key top left

plot [-0.5:0.5][:0.26]\
     'u-1-1.' u 1:2 w l t 'a=1' lt 1, 'u-1-1.' u 1:4 w l t '' lt 1, \
     'u-2-1.' u 1:2 w l t 'a=2' lt 2, 'u-2-1.' u 1:4 w l t '' lt 2, \
     'u-4-1.' u 1:2 w l t 'a=4' lt 3, 'u-4-1.' u 1:4 w l t '' lt 3, \
     'u-8-1.' u 1:2 w l t 'a=8' lt 4, 'u-8-1.' u 1:4 w l t '' lt 4, \
     'u-16-1.' u 1:2 w l t 'a=16' lt 5, 'u-16-1.' u 1:4 w l t '' lt 5

set output 'uminmax-400.eps'
plot 'u-1-400.' u 1:2 w l t 'a=1' lt 1, 'u-1-400.' u 1:4 w l t '' lt 1, \
     'u-2-400.' u 1:2 w l t 'a=2' lt 2, 'u-2-400.' u 1:4 w l t '' lt 2, \
     'u-4-400.' u 1:2 w l t 'a=4' lt 3, 'u-4-400.' u 1:4 w l t '' lt 3, \
     'u-8-400.' u 1:2 w l t 'a=8' lt 4, 'u-8-400.' u 1:4 w l t '' lt 4, \
     'u-16-400.' u 1:2 w l t 'a=16' lt 5, 'u-16-400.' u 1:4 w l t '' lt 5
EOF

for r in 1 2 4 8 16; do
    for re in $lowRe 400.; do
	echo "Save stdout { format = Gnuplot }" | gfsview-batch2D end-$r-$re.gfs znull.gfv | awk -v ratio=$r '{ if (NF == 3) print $1/ratio,$2; else print $0;}' > znull-$r-$re
    done
done

gnuplot <<EOF
set term postscript eps color lw 2 18 enhanced
set output 'znull-1.eps'
set xlabel 'x/a'
set ylabel 'z where u(x,z)=0'
set key top center

plot [-0.448:0.498][-0.35:0]\
     'znull-1-1.' u 1:2 w l t 'a=1' lt 1,\
     'znull-2-1.' u 1:2 w l t 'a=2' lt 2,\
     'znull-4-1.' u 1:2 w l t 'a=4' lt 3,\
     'znull-8-1.' u 1:2 w l t 'a=8' lt 4,\
     'znull-16-1.' u 1:2 w l t 'a=16' lt 5

set key top right
set output 'znull-400.eps'
plot [-0.498:0.498][-0.35:0]\
     'znull-1-400.' u 1:2 w l t 'a=1' lt 1,\
     'znull-2-400.' u 1:2 w l t 'a=2' lt 2,\
     'znull-4-400.' u 1:2 w l t 'a=4' lt 3,\
     'znull-8-400.' u 1:2 w l t 'a=8' lt 4,\
     'znull-16-400.' u 1:2 w l t 'a=16' lt 5
EOF

for r in 1 2 4 8 16; do
    for re in $lowRe 400.; do
	gawk '{ if ($1 != "#" && $10 < 1.) print $1,$4;}' < end-$r-$re.txt | sort -n -k1,2 > pb-$r-$re
    done
done

gnuplot <<EOF
set term postscript eps color lw 2 18 enhanced
set output 'convergence-pressure-400.eps'
set xlabel 'x'
set ylabel 'Pressure'
set key top left

plot 3/2.*1./400.*x t 'analytical' lt 0, 'pb-1-400.' u 1:(\$2-0.0063) w l t 'a = 1' lt 1, 'pb-2-400.' u 1:(\$2-0.0071) w l t 'a = 2' lt 2, 'pb-4-400.' u 1:(\$2-0.01) w l t 'a = 4' lt 3, 'pb-8-400.' u 1:(\$2-0.02) w l t 'a = 8' lt 4, 'pb-16-400.' u 1:(\$2-0.044) w l lt 5 t 'a = 16'

set output 'convergence-pressure-1.eps'
plot 3/2.*x t 'analytical' lt 0, 'pb-1-1.' u 1:(\$2-2.83) w l t 'a = 1' lt 1, 'pb-2-1.' u 1:(\$2-3.94) w l t 'a = 2' lt 2, 'pb-4-1.' u 1:(\$2-6.23) w l t 'a = 4' lt 3, 'pb-8-1.' u 1:(\$2-11.42) w l t 'a = 8' lt 4, 'pb-16-1.' u 1:(\$2-22.09) w l lt 5 t 'a = 16'
EOF
