for r in 1 2 4 8; do 
    echo $r-400.
    gerris2D -DRATIO=$r -DRE=400. -DDTMAX=0.1 -DDUMIN=5e-4 lake.gfs 2> log-$r-400. > /dev/null;
    echo "Save slope-$r-400. { format = Gnuplot }" | gfsview-batch2D end-$r-400..gfs slope.gfv
    awk 'BEGIN{np=0; avg = 0.;} {
      if ($2==-2.*0.03125/4.) {
        x[np] = $1;
        p[np++] = $4;
        avg += $4;
      }
    }END {
      avg /= np;
      for (i = 0; i < np; i++)
        print x[i],p[i]-avg;
    }' < ./end-$r-400..txt > sp-$r-400.
done

echo "Save vectors-400.eps { format = EPS }" | gfsview-batch2D end-4-400..gfs vectors.gfv

gnuplot <<EOF
set term postscript eps color lw 2 18

set output 'convergence-pressure-400.eps'
set xlabel 'x'
set ylabel 'Surface pressure'
set key top left
Re=400.
alpha=1./Re
plot 60./13.*alpha*x t 'analytical', \
  'sp-1-400.' t 'a=1', \
  'sp-2-400.' t 'a=2', \
  'sp-4-400.' t 'a=4', \
  'sp-8-400.' t 'a=8'

set output 'convergence-thermocline-400.eps'
set xlabel 'x'
set ylabel 'Thermocline position'
set key top right
alphat=1./Re
plot 3/4.-64./13.*alphat*x t 'analytical', \
  'slope-1-400.' u 1:(\$2+1.) t 'a=1', \
  'slope-2-400.' u 1:(\$2+1.) t 'a=2', \
  'slope-4-400.' u 1:(\$2+1.) t 'a=4', \
  'slope-8-400.' u 1:(\$2+1.) t 'a=8'

set output 'profile.eps'
set xlabel 'z'
set ylabel 'u'
set key top left
u(x)=(x > 3./4. ? 30.*x*x - 47.*x + 18. : -2.*x*x + x)/13.
plot [0:1] u(x) t 'analytical', 'lake-4-400.' u (1.+\$1):2 ps 2 t 'Gerris'

set output 'convergence-400.eps'
plot [0:1] u(x) t 'analytical', 'lake-1-400.' u (1.+\$1):2 ps 1 t 'a = 1', 'lake-2-400.' u (1.+\$1):2 ps 1 t 'a = 2', 'lake-4-400.' u (1.+\$1):2 ps 1 t 'a = 4', 'lake-8-400.' u (1.+\$1):2 ps 1 t 'a = 8'

set output 'xprofile-400.eps'
set xlabel 'x'
set ylabel 'RMS Error'
set key top right
plot 'ep-1-400.' w lp t 'a=1', 'ep-2-400.' w lp t 'a=2', 'ep-4-400.' w lp t 'a=4', 'ep-8-400.' w lp t 'a=8'

set output 'xprofile-lateral-400.eps'
set xlabel '|x|-a/2'
plot 'ep-1-400.' u (abs(\$1)-0.5):2 w lp t 'a=1', 'ep-2-400.' u (abs(\$1)-1.):2 w lp t 'a=2', 'ep-4-400.' u (abs(\$1)-2.):2 w lp t 'a=4', 'ep-8-400.'  u (abs(\$1)-4.):2 w lp t 'a=8'

set output 'wprofile-400.eps'
set xlabel 'x'
set ylabel 'Depth-averaged vertical velocity'
set key bottom left
plot 'ep-1-400.' u 1:3 w lp t 'a=1', 'ep-2-400.' u 1:3 w lp t 'a=2', 'ep-4-400.' u 1:3 w lp t 'a=4', 'ep-8-400.' u 1:3 w lp t 'a=8'

set output 'wprofile-lateral-400.eps'
set key bottom left
plot 'ep-1-400.' u (abs(\$1)-0.5):3 w lp t 'a=1', 'ep-2-400.' u (abs(\$1)-1.):3 w lp t 'a=2', 'ep-4-400.' u (abs(\$1)-2.):3 w lp t 'a=4', 'ep-8-400.'  u (abs(\$1)-4.):3 w lp t 'a=8'

EOF
